==> jc-1.4.0.tar.gz: java/awt/PageAttributes__24ColorType.h <==
// public final class java.awt.PageAttributes$ColorType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 62e11a03154add56 java_awt_PageAttributes__24ColorType
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_PageAttributes__24ColorType_H_
#define _JC_java_awt_PageAttributes__24ColorType_H_

// Forward structure declarations
struct _jc_java_awt_PageAttributes__24ColorType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_PageAttributes__24ColorType$sub_refs	_jc_java_awt_PageAttributes__24ColorType$sub_refs;
typedef struct _jc_java_awt_PageAttributes__24ColorType$sub_nonrefs	_jc_java_awt_PageAttributes__24ColorType$sub_nonrefs;
typedef struct _jc_java_awt_PageAttributes__24ColorType$refs	_jc_java_awt_PageAttributes__24ColorType$refs;
typedef struct _jc_java_awt_PageAttributes__24ColorType$nonrefs	_jc_java_awt_PageAttributes__24ColorType$nonrefs;
typedef struct _jc_java_awt_PageAttributes__24ColorType$object	_jc_java_awt_PageAttributes__24ColorType$object;

typedef struct _jc_java_awt_PageAttributes__24ColorType$fields_struct	_jc_java_awt_PageAttributes__24ColorType$fields_struct;
typedef const struct _jc_java_awt_PageAttributes__24ColorType$vmethods	_jc_java_awt_PageAttributes__24ColorType$vmethods;
typedef const struct _jc_java_awt_PageAttributes__24ColorType$vtable	_jc_java_awt_PageAttributes__24ColorType$vtable;
typedef const struct _jc_java_awt_PageAttributes__24ColorType$vtype	_jc_java_awt_PageAttributes__24ColorType$vtype;

// Class fields structure
struct _jc_java_awt_PageAttributes__24ColorType$fields_struct {
	struct _jc_java_awt_PageAttributes__24ColorType$object	*COLOR;
	struct _jc_java_awt_PageAttributes__24ColorType$object	*MONOCHROME;
	_jc_object_array	*NAMES;
};
extern _jc_java_awt_PageAttributes__24ColorType$fields_struct _jc_java_awt_PageAttributes__24ColorType$class_fields;

// Constructors
extern void _jc_java_awt_PageAttributes__24ColorType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_PageAttributes__24ColorType$object *, jint);

// Static methods
extern void _jc_java_awt_PageAttributes__24ColorType$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_PageAttributes__24ColorType$vmethods {
};

// Vtable
struct _jc_java_awt_PageAttributes__24ColorType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_PageAttributes__24ColorType$vmethods	java_awt_PageAttributes__24ColorType;
};

// Vtype
struct _jc_java_awt_PageAttributes__24ColorType$vtype {
	_jc_type			type;
	_jc_java_awt_PageAttributes__24ColorType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24ColorType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_PageAttributes__24ColorType$refs {
    _jc_java_awt_PageAttributes__24ColorType$sub_refs	java_awt_PageAttributes__24ColorType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24ColorType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PageAttributes__24ColorType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_PageAttributes__24ColorType$sub_nonrefs	java_awt_PageAttributes__24ColorType;
};

// Object instance structure
struct _jc_java_awt_PageAttributes__24ColorType$object {
	_jc_java_awt_PageAttributes__24ColorType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PageAttributes__24ColorType$vtype	*vtype;
	_jc_java_awt_PageAttributes__24ColorType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PageAttributes__24ColorType$vtype _jc_java_awt_PageAttributes__24ColorType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PageAttributes__24ColorType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PageAttributes__24ColorType$class_object;

#endif	/* _JC_java_awt_PageAttributes__24ColorType_H_ */

==> jc-1.4.6.tar.gz: java/awt/PageAttributes__24ColorType.h <==
// public final class java.awt.PageAttributes$ColorType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 62e11a03154add56 java_awt_PageAttributes__24ColorType
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_PageAttributes__24ColorType_H_
#define _JC_java_awt_PageAttributes__24ColorType_H_

// Forward structure declarations
struct _jc_java_awt_PageAttributes__24ColorType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_PageAttributes__24ColorType$sub_refs	_jc_java_awt_PageAttributes__24ColorType$sub_refs;
typedef struct _jc_java_awt_PageAttributes__24ColorType$sub_nonrefs	_jc_java_awt_PageAttributes__24ColorType$sub_nonrefs;
typedef struct _jc_java_awt_PageAttributes__24ColorType$refs	_jc_java_awt_PageAttributes__24ColorType$refs;
typedef struct _jc_java_awt_PageAttributes__24ColorType$nonrefs	_jc_java_awt_PageAttributes__24ColorType$nonrefs;
typedef struct _jc_java_awt_PageAttributes__24ColorType$object	_jc_java_awt_PageAttributes__24ColorType$object;

typedef struct _jc_java_awt_PageAttributes__24ColorType$fields_struct	_jc_java_awt_PageAttributes__24ColorType$fields_struct;
typedef const struct _jc_java_awt_PageAttributes__24ColorType$vmethods	_jc_java_awt_PageAttributes__24ColorType$vmethods;
typedef const struct _jc_java_awt_PageAttributes__24ColorType$vtable	_jc_java_awt_PageAttributes__24ColorType$vtable;
typedef const struct _jc_java_awt_PageAttributes__24ColorType$vtype	_jc_java_awt_PageAttributes__24ColorType$vtype;

// Class fields structure
struct _jc_java_awt_PageAttributes__24ColorType$fields_struct {
	struct _jc_java_awt_PageAttributes__24ColorType$object	*COLOR;
	struct _jc_java_awt_PageAttributes__24ColorType$object	*MONOCHROME;
	_jc_object_array	*NAMES;
};
extern _jc_java_awt_PageAttributes__24ColorType$fields_struct _jc_java_awt_PageAttributes__24ColorType$class_fields;

// Constructors
extern void _jc_java_awt_PageAttributes__24ColorType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_PageAttributes__24ColorType$object *, jint) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_awt_PageAttributes__24ColorType$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_PageAttributes__24ColorType$vmethods {
};

// Vtable
struct _jc_java_awt_PageAttributes__24ColorType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_PageAttributes__24ColorType$vmethods	java_awt_PageAttributes__24ColorType;
};

// Vtype
struct _jc_java_awt_PageAttributes__24ColorType$vtype {
	_jc_type			type;
	_jc_java_awt_PageAttributes__24ColorType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24ColorType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_PageAttributes__24ColorType$refs {
    _jc_java_awt_PageAttributes__24ColorType$sub_refs	java_awt_PageAttributes__24ColorType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24ColorType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PageAttributes__24ColorType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_PageAttributes__24ColorType$sub_nonrefs	java_awt_PageAttributes__24ColorType;
};

// Object instance structure
struct _jc_java_awt_PageAttributes__24ColorType$object {
	_jc_java_awt_PageAttributes__24ColorType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PageAttributes__24ColorType$vtype	*vtype;
	_jc_java_awt_PageAttributes__24ColorType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PageAttributes__24ColorType$vtype _jc_java_awt_PageAttributes__24ColorType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PageAttributes__24ColorType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PageAttributes__24ColorType$class_object;

#endif	/* _JC_java_awt_PageAttributes__24ColorType_H_ */
